__code__='GatU0D/[on&>$QoP+t8J.4oJ_QB:B8[<K8^<>?uH!_%.4d9Rm^dE6JlS&E6XS)(d=,)&f8nV."]?gGqiL4i)?dC\\6)H?WtmB4a:?6LgPCq&<\'"Q3:NK+\\<R[J-\'$X]EJ"V-pS)Fd:2Yb<!A@Q\'sImE#AaA]".TF_#&F>^#Q+Ym"Q2ke;h-ZSVZCE2cN)5kIL167n12;X!RCe<#J:%]&b$Fk2h:LQEp?emZ0qX=&cScFYQi!+W!5%S2,JF?=U"?n%BM^p_,E[eb]65W^4el=$H6BVM7\'RHY<qi)Nc0r2E\\UC$\']LVD_^b9`/_13.,\\k<bZMHp`LOadRB4"WS!pnC7Z?IL#\\mR&M:=W4qY<[9?e0Cds4T$FD\\]bY3ju>q^dJ,6j8%mHLq^mQ.a%1"r)d\'.XS^n=\'fI44EMHs7eeROm1fA&s1iM\'!sdiOoOb6[E*MZ\\.>YgfqH=<7<]UOBIsVdji$.<[a^)o\\[1?;G\'IB7%obbLi/L@Va@*ZXQDrE_,\'Xr?N4/hmZ>S1.lO+o.)?`dR<c+9B=F[cnFk1Y\\4:YftG5;/CRPk<L.Cc"m^3JHT[CPOb&Id:aJT)bVZR2X\\:Y`k\\XIlrR0rsmd@NkgPgdXG*n<D1ABSq9UhVH4$bt=Cm68%eP],I8<_(Jc1VXZ@otLgjeeUWXda&gc>6)5P?(s6%p46PHeBssie,$jPW$b9VQ&(&@-p%.A^=UF*)M3*"<`bT`E[V\'&fX[8hCH!oV!NG[PM\'&n>CfZ=gjHYF:X\\k2eSA6#gqIstk3X*P(IsP2llkMP\'!$*e`&Z5A^UiPh>!sT!Ih0ca]HWPjOi9)"g%EPt([74m\\"dK?b]nU#/NLK7(<S^D1c_/ZIGd`th(>lF\\Ih67_SX-]VKkEMh(HFT-dM0GKju.V4o$?qA!^<L>.FLqAZtlk`+5!gs-]P"FWOl!2F)DMpB,.7)r(sq2dsrg"Lda+(rh!u7>YFe>2Sf?U!ms<55F!.DQqG\\7u=pt[Pc*oMcu@L\\`]rt%JbGaa+Ot7T4\'pd.7I9sN+93]jA+T0TDtN@n&#&]mj322YPH#brgCd5Qkk[Br6JC*7&0;pR4E]e~>'



__code__='Gat=(s)6@U\'RuIZTe-\\a;V9W0GVHRVKYt:(Bptp(OD[U,<fo_GYfUqaY-"[5S+BpT9\')rpm?dcOqoe]ifd8.=6Y[RTZg[=1^-):!">bO/l2$gNia3%;*C^%DU&Y=@"!!@?0G5K3*!+qjrW_$UUgFe^!Ls7.!M0@_#@%76"?[-<#4NkQZ[h3=QN05S>R!;$\\,pmUn06d<J=cmL!rNJrF25tL<rfu8]Lja<?8e5;nR%XA:Z?P*1^C>*$D[cE%ZZu#?MsuD(Cn)#Fr0X@Q9$3!f3lu)MJO+q@2OjD,*,I0IUS_t.3&E]UpWPo8#7$<VVVS*UrPdURGp%R*1iUoX33IdQV5,fJ;^V#TIoA9P<h`InJg[]4k$d$[0)0na</r:"]tCgJ4OOF9>\\D\'9ej.T"RAjUoJ_)W=#\\jWBMMFWQ9*N!)4jq>P="!VU7139%:u>@c;gD"dXl!\',[8hmC=p_>fJX0W2q\'\\>ZGCKZM4A5ohS/GAn@n3&.dBth*M_Yjka9UG5qbI,fm1kF`Or>BU0&1(_NGAA4R\\W:GqB<ME%HXW/D>l!L*km"1\\U@($\'T,[qTi&BJ[\\d#Q\'>ekq$hq>b-eF8@1*R@PEe?N%*TWLmSfNd9)ISE]C%m&\\8gJ^DA#Gp/L7p<,/KCbZ`TXD4\'Lf3F?9<rqjt*W8\\""Rg":@=jM#Op)LHg>@R;)JWLG><:@_L!@[,sZa5NDO;OoSn\\)+]a;C:#\'O:PrGNB<?sU"sL=O23otpS99@X3NJ%8YXaR\'@qPPmC8jIiB;e@s15aReYG7%g.aN6h^dASU2tCNU7JNM?CAOY2eQj;GN\\B7qE;Lgm=U2g^TWrpRH7r$T;5YjP[mpj]g\'*jCV#AC]KRWREILp0Y]-Yt\'!ghm,oWO!)=>H.G$XWYdI15PqCU4cn4$:Gq;#&W1:(jagoW8*,ZXo[gMaUYOR6*+hK+T:OHEDF5&d.7=^haXeU<k#fiHpFphQ=G_l_sqYat;A<"2=K]na3kK0&$:$uJ)br;KA+Wt$AoOf$%i[Rn\\dQL`+:R%3fEZ/WP#?X_cNF[?=N3o?R8%,:ArD[V.N8Ouo3Q.&j6Po4?t0\'pHXNI/_"h@t2aq#n93aH\'nNqM@e$>?lVs^9o(!7-f@%0/ZcuX778t6_W`~>'



__code__='Gas1]gMYb8&=k*r=]X<G;;ANmPD7>Y[0i/@X_CWH70>t-%+)!d-#oWc+DB\'SAk\\?2Eb3FIoAfn"l&YHqqAF\\J?hC<RZkt;b@;0qig7:6:B!c4NJ[s*,RQo3Dr[*9L@0H\'U$:\'-n_"Pj"OT6ig#^A*&"/Grg_Z[=HCOgQC"i(?#,%))R%,_cV#CpFfcN1HScNCTV0*!U,IL(01n0>`0!A=J&!r+5&A\\]gHT)i7EQ?+]Qk\'Hh"Ab_7p/K!#\'ei<hHJZQ\\M$0(\'=YjpM#kJV6?Ia4pQ.#2Rlm+a#-7PJ2B=V]#Cb-D:&CIAnn=WO[LN(j42lrZlAf,ub[_:EGr(grUj,iDM7`E+C"J3t5%K2><G+1.tibVDh.^nCenK?@251QMYEi[:`lI`B!fH0^Mm#>b1,+$JkU`PT(5^=K;daC^?6Wkqk^XMW+jZrMpl0ZVl?aOlIO!nErsr`rB`S8./8IFl$mI+unFd%0QG-T[3lmUS,1cq+`T,>G_ON5In;79d,eDJ_@I9)&kAMuBpQ]V=Y9irg_AYEqB?ji!4?:K3P;9%#`+aG-0r0Jo7F0esgZL\\[D;=Jgr\'Y.n\\S]2+3*R+]1oKn51=M0>nT,g^_?2<VHDFo$Nq]>),LW,a]b2k;\'/4#ULWgt_/_q9d.4@1q=OZK3nP\'k%8;HLNg(\'2jo\\6#OEb99bm@\\fsAp^R*]?s/CH_q=Sq=glj5Jb]K$#8eRCQG$T1\\CNG?Y:u;AO$J4l2]d2/mp#Y7Zjh5hZLr)n7.bO8Iktp<l@!)+fXkU<ugqWg4^&*#gj3=KIqZLIfel\'J96j`O9mH%].@m2oHi?[2]J,IN^/IA<;k,i#]#.n<V?$27;h1"4`qH<b-2`!dEH]RaZ2kB(rHclpEM&c.\\hQ2a#?+q]4o(Gla\',Bd7qcT:SAW,CNQnMLRd[rm=qB`3,Kdbi6<rf<VZBZD4?j=:T:"Uj_-3c7toDQZ_cub1Kc\\aAj7hfG/c;cL^?E(Fb9PB\\?["N2aUX0T!;Q!ACGb-!G"B?XMN*Fdu/]V!;FpkRQ=Cu-ks/Di.r,Aa@+#uI\\MG"X"lAK+Ke5,mH16tAbp^a[.A:j~>'
